@@ -7,7 +7,7 @@ Simple redis-backed, distributed sorted sets.
 
 """
 
-__version__ = '0.4'
+__version__ = '0.4.2'
 
 from redset.sets import *
-
+import serializers
